@@ -10,9 +10,9 @@ use Exporter qw(import);
 use Perinci::Sub::Util qw(gen_modified_sub);
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-11-13'; # DATE
+our $DATE = '2022-11-14'; # DATE
 our $DIST = 'App-UniqFiles'; # DIST
-our $VERSION = '0.137'; # VERSION
+our $VERSION = '0.138'; # VERSION
 
 our @EXPORT_OK = qw(uniq_files);
 
@@ -250,7 +250,7 @@ _
         },
         {
             summary   => 'List all files (recursively, and in detail) which have duplicate contents (all duplicate copies), exclude some files',
-            src       => q(uniq-files -R -l -d -x '\.git/' --min-size 10k .),
+            src       => q(uniq-files -R -l -d -X '\.git/' --min-size 10k .),
             src_plang => 'bash',
             test      => 0,
             'x.doc.show_result' => 0,
@@ -570,6 +570,12 @@ sub uniq_files {
 gen_modified_sub(
     base_name => 'uniq_files',
     output_name => 'dupe_files',
+    description => <<'_',
+
+This is a thin wrapper to <prog:uniq-files>. It defaults `report_unique` to 0
+and `report_duplicate` to 1.
+
+_
     modify_args => {
         report_unique => sub {
             $_[0]{schema} = [bool => {default=>0}];
@@ -612,7 +618,7 @@ App::UniqFiles - Report or omit duplicate file contents
 
 =head1 VERSION
 
-This document describes version 0.137 of App::UniqFiles (from Perl distribution App-UniqFiles), released on 2022-11-13.
+This document describes version 0.138 of App::UniqFiles (from Perl distribution App-UniqFiles), released on 2022-11-14.
 
 =head1 SYNOPSIS
 
@@ -631,8 +637,8 @@ Usage:
 
 Report or omit duplicate file contents.
 
-Given a list of filenames, will check each file size and content for duplicate
-content. Interface is a bit like the C<uniq> Unix command-line program.
+This is a thin wrapper to L<uniq-files>. It defaults C<report_unique> to 0
+and C<report_duplicate> to 1.
 
 This function is not exported.
 
